ReadState

Struct ReadState 

pub struct ReadState<'buf> {
    pub index: usize,
    pub eof: bool,
    pub is_framable: bool,
    pub shift: bool,
    pub total_consumed: usize,
    pub buffer: &'buf mut [u8],
}
Internal state for reading frames.

Fields

index: usize

The current index in the buffer.

Represents the number of bytes read into the buffer.

eof: bool

EOF was reached while decoding.

is_framable: bool

The buffer is currently framable.

shift: bool

The buffer must be shifted before reading more bytes.

Makes room for more bytes to be read into the buffer, keeping the already read bytes.

total_consumed: usize

Total number of bytes decoded in a framing round.

buffer: &'buf mut [u8]

The underlying buffer to read into.

Implementations

Source

impl<'buf> ReadState<'buf>

pub const fn new(buffer: &'buf mut [u8]) -> Self

Creates a new ReadState.

pub const fn reset(self) -> Self

Resets the state to its initial values.

pub const fn empty() -> Self

Creates an empty ReadState.

pub const fn framable(&self) -> usize

Returns the number of bytes that can be framed.