pub struct ReadState<'buf> {
pub index: usize,
pub eof: bool,
pub is_framable: bool,
pub shift: bool,
pub total_consumed: usize,
pub buffer: &'buf mut [u8],
}Expand description
Internal state for reading frames.
Fields
index: usizeThe current index in the buffer.
Represents the number of bytes read into the buffer.
eof: boolEOF was reached while decoding.
is_framable: boolThe buffer is currently framable.
shift: boolThe buffer must be shifted before reading more bytes.
Makes room for more bytes to be read into the buffer, keeping the already read bytes.
total_consumed: usizeTotal number of bytes decoded in a framing round.
buffer: &'buf mut [u8]The underlying buffer to read into.
Implementations